@@ -1,9 +1,9 @@
 #
-# $Id: Split.pm,v 0.48 2004/01/07 17:00:37 sts Exp $
+# $Id: Split.pm,v 0.49 2004/01/07 20:43:35 sts Exp $
 
 package Dir::Split;
 
-our $VERSION = '0.48';
+our $VERSION = '0.49';
 
 use 5.6.1;
 use strict 'vars';
@@ -21,6 +21,7 @@ our (# external data
         %track,
 
         $traverse,
+        $traverse_depth,
         $traverse_unlink,
         $traverse_rmdir,
 
@@ -638,7 +639,7 @@ sub _traverse {
       map { File::Spec->catfile($o->{'source'}, $_) }
       @eval;
 
-    RECURSE:
+    TRAVERSE:
     while (@eval) {
         if (-d $eval[0]) {
             $eval = shift @eval;
@@ -661,7 +662,9 @@ sub _traverse {
         }
 
         unless (@eval) {
-            #if ($limit && ++$count == $limit) { last RECURSE }
+            if (++$count == ${__PACKAGE__.'::traverse_depth'}) {
+                last TRAVERSE;
+            }
             @eval = @stack;
             undef @stack;
         }
@@ -679,8 +682,11 @@ sub _traverse {
 
 sub _traversed_rm_dir {
     if (${__PACKAGE__.'::traverse_rmdir'}) {
-        foreach (@Dirs) {
-            rmtree($_, 1, 1);
+        if (!${__PACKAGE__.'::traverse_depth'}
+          && ${__PACKAGE__.'::traverse_unlink'}) {
+            foreach (@Dirs) {
+                rmtree($_, 1, 1);
+            }
         }
     }
 }
@@ -944,14 +950,27 @@ an argument to the object constructor, it requires the following variable to be
  # traversal mode
  $Dir::Split::traverse        = 1;
 
-Additionally some options:
+By default no depth limit e.g. all underlying directories / files will be evaluated.
+
+B<options>
+
+ # traversing depth
+ $Dir::Split::traverse_depth  = 3;
+
+The traversal depth equals the directory depth that will be entered.
 
  # unlink files in source
  $Dir::Split::traverse_unlink = 1;
 
+Unlinks files after they have been moved to their new locations.
+
  # remove directories in source
  $Dir::Split::traverse_rmdir  = 1;
 
+Removes the directories themselves after the files have been moved. In order to take effect,
+this option requires the C<$Dir::Split::traverse_unlink> to be set. Directories will not be
+removed if a traversing depth has been set.
+
 It is B<NOT> recommended to turn on the latter options C<$Dir::Split::traverse_unlink> and
 C<$Dir::Split::traverse_rmdir>, unless you're aware of the consequences they imply.
 
@@ -1021,7 +1040,7 @@ should be well grounded.
 
 =head1 DEPENDENCIES
 
-C<Perl 5.6.1>; C<File::Copy>, C<File::Path>, C<File::Spec>.
+C<Perl 5.6.1>; C<File::Basename>, C<File::Copy>, C<File::Path>, C<File::Spec>.
 
 =head1 SEE ALSO
 
